Learn R Programming

madshapR (version 2.0.0)

check_name_standards: Assess variable names in a data dictionary for non-standard formats

Description

Generates a data frame report of any variable names that are not compatible in Maelstrom Research ecosystem, including Opal. This report can be used to help assess data structure, presence of fields, coherence across elements, and taxonomy or data dictionary formats.

Usage

check_name_standards(var_names)

Value

A data frame providing non-standard names across a vector.

Arguments

var_names

A character vector of names.

Details

The object may be specifically formatted to be compatible with additional Maelstrom Research software, in particular Opal environments.

Examples

Run this code
{

# use madshapR_examples provided by the package
names_in_data_dict <- 
  madshapR_examples$`data_dictionary_example - errors`$`Variables`$`name`
check_name_standards(names_in_data_dict)
check_name_standards(c("coucou", "cou cou", "$coucou",NA))

}

Run the code above in your browser using DataLab