Learn R Programming

madshapR (version 2.0.0)

madshapR_website: Call to online documentation

Description

Direct call to the online documentation for the package, which includes a description of the latest version of the package, vignettes, user guides, and a reference list of functions and help pages.

Usage

madshapR_website()

Arguments

Value

Nothing to be returned. The function opens a web page.

Examples

Run this code
{

madshapR_website()

}

Run the code above in your browser using DataLab